==> pyAWM-1.0.2.tar.gz: pyAWM-1.0.2/setup.py <==

from distutils.core import setup
setup(
  name = 'pyAWM',         # How you named your package folder (MyLib)
  packages = ['pyAWM'],   # Chose the same as "name"
  # package_dir={'': 'C:/Users/aswanth kumar/Desktop'},
  version = '1.0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This library automates your whatsapp messages, files, media. It Schedules your messages at given time',   # Give a short description about your library
  long_description=open('README.txt').read(),
  long_description_content_type="text/markdown",
  author = 'Kalyan Pavan Latchipatruni',                   # Type in your name
  author_email = 'kaluyanpavan1179@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/kalyan1179/Automate-WhatsApp-Messages-with-Python',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/kalyan1179/Automate-WhatsApp-Messages-with-Python/archive/1.0.1.tar.gz',    # I explain this later on
  keywords = ['WHATSAPP', 'AUTOMATE', 'MESSAGE', 'AUTOMATION', 'SEND'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'selenium',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> pyAWM-1.0.3.tar.gz: pyAWM-1.0.3/setup.py <==

from distutils.core import setup
setup(
  name = 'pyAWM',         # How you named your package folder (MyLib)
  packages = ['pyAWM'],   # Chose the same as "name"
  # package_dir={'': 'C:/Users/aswanth kumar/Desktop'},
  version = '1.0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This library automates your whatsapp messages, files, media. It Schedules your messages at given time',   # Give a short description about your library
  long_description=open('README.txt').read(),
  long_description_content_type="text/markdown",
  author = 'Kalyan Pavan Latchipatruni',                   # Type in your name
  author_email = 'kalyanpavan1179@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/kalyan1179/Automate-WhatsApp-Messages-with-Python',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/kalyan1179/Automate-WhatsApp-Messages-with-Python/archive/1.0.1.tar.gz',    # I explain this later on
  keywords = ['WHATSAPP', 'AUTOMATE', 'MESSAGE', 'AUTOMATION', 'SEND'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'selenium',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
